Skip to contents

A lightweight family object describing the asymmetric Laplace distribution (ALD) working likelihood used by bqmm(). It mirrors the role of a stats::family object but is intentionally minimal in this release.

Usage

ald(link = "identity")

Arguments

Name of the link for the location (quantile) parameter. Only "identity" is supported in v0.1.

Value

An object of class "bqmm_family".

Examples

ald()
#> bqmm family: asymmetric Laplace (link = identity )