A lightweight family object describing the asymmetric Laplace distribution
(ALD) working likelihood used by bqmm(). It mirrors the role of a
stats::family object but is intentionally minimal in this release.
A lightweight family object describing the asymmetric Laplace distribution
(ALD) working likelihood used by bqmm(). It mirrors the role of a
stats::family object but is intentionally minimal in this release.